@@ -620,6 +620,8 @@ static ClutterActor* _xfdashboard_gnome_shell_search_provider_create_result_acto
 	self=XFDASHBOARD_GNOME_SHELL_SEARCH_PROVIDER(inProvider);
 	priv=self->priv;
 	actor=NULL;
+	name=NULL;
+	description=NULL;
 	icon=NULL;
 	error=NULL;
 
@@ -851,7 +853,7 @@ static gboolean _xfdashboard_gnome_shell_search_provider_activate_result(Xfdashb
 
 	proxyResult=g_dbus_proxy_call_sync(proxy,
 										"ActivateResult",
-										g_variant_new("(s(^as)u)",
+										g_variant_new("(s^asu)",
 														identifier,
 														inSearchTerms,
 														clutter_get_current_event_time()),
@@ -925,7 +927,7 @@ static gboolean _xfdashboard_gnome_shell_search_provider_launch_search(Xfdashboa
 
 	proxyResult=g_dbus_proxy_call_sync(proxy,
 										"LaunchSearch",
-										g_variant_new("((^as)u)",
+										g_variant_new("(^asu)",
 														inSearchTerms,
 														clutter_get_current_event_time()),
 										G_DBUS_CALL_FLAGS_NONE,
